@@ -14,6 +14,7 @@
 #' @import tidyverse
 #' @importFrom rvest read_html html_nodes html_table
 #' @importFrom stringr str_extract
+#' @importFrom curl has_internet
 #' @export
 #' @examples \dontrun{
 #' # NSE IPO's
@@ -22,6 +23,11 @@
 #' }
 #'
 fdii = function(){
+  #  check internet connection
+  if (!curl::has_internet()) {
+    message("No internet connection.")
+    return(invisible(NULL))
+  }
 
   url = 'https://www.moneycontrol.com/stocks/marketstats/fii_dii_activity/index.php'
   dat = url %>%
